Module traits

Module traits 

Traits

ContainerIdentidy
HeartbeatConfigProvider
Provides heartbeat configuration from a component’s parsed XML config. Implement this on your top-level Config struct. Return None to disable heartbeats.
HyperionContainerDirectiveMessage
HyperionHeartbeatMessage
Allows the container infrastructure to construct and parse heartbeat messages from the application’s message type T without knowing what T is. Implement this on your top-level message enum (e.g. ContainerMessage).
Initialisable
LogLevel
Run